/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizorderconfig.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizorderconfig.entity.BizOrderConfig;
import vip.xiaonuo.biz.modular.bizorderconfig.mapper.BizOrderConfigMapper;
import vip.xiaonuo.biz.modular.bizorderconfig.param.BizOrderConfigAddParam;
import vip.xiaonuo.biz.modular.bizorderconfig.param.BizOrderConfigEditParam;
import vip.xiaonuo.biz.modular.bizorderconfig.param.BizOrderConfigIdParam;
import vip.xiaonuo.biz.modular.bizorderconfig.param.BizOrderConfigPageParam;
import vip.xiaonuo.biz.modular.bizorderconfig.service.BizOrderConfigService;

import java.util.List;

/**
 * 订单配置Service接口实现类
 *
 * @author fanzherong
 * @date  2025/04/03 15:13
 **/
@Service
public class BizOrderConfigServiceImpl extends ServiceImpl<BizOrderConfigMapper, BizOrderConfig> implements BizOrderConfigService {

    @Override
    public Page<BizOrderConfig> page(BizOrderConfigPageParam bizOrderConfigPageParam) {
        QueryWrapper<BizOrderConfig> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizOrderConfigPageParam.getOrderId())){
            queryWrapper.eq("boc.order_id",bizOrderConfigPageParam.getOrderId());
        }
        queryWrapper.eq("boc.delete_flag","NOT_DELETE");
        Page<BizOrderConfig> config = this.getBaseMapper().getConfig(CommonPageRequest.defaultPage(), queryWrapper);
        return config;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizOrderConfigAddParam bizOrderConfigAddParam) {
        //根据订单id查询是否添加过
        long count = this.count(new QueryWrapper<BizOrderConfig>().lambda().eq(BizOrderConfig::getOrderId, bizOrderConfigAddParam.getOrderId()));
        if(count>0){
            throw new CommonException("扫码次数配置已添加，无需重复添加！");
        }
        BizOrderConfig bizOrderConfig = BeanUtil.toBean(bizOrderConfigAddParam, BizOrderConfig.class);
        this.save(bizOrderConfig);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizOrderConfigEditParam bizOrderConfigEditParam) {
        BizOrderConfig bizOrderConfig = this.queryEntity(bizOrderConfigEditParam.getId());
        BeanUtil.copyProperties(bizOrderConfigEditParam, bizOrderConfig);
        this.updateById(bizOrderConfig);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizOrderConfigIdParam> bizOrderConfigIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizOrderConfigIdParamList, BizOrderConfigIdParam::getId));
    }

    @Override
    public BizOrderConfig detail(BizOrderConfigIdParam bizOrderConfigIdParam) {
        return this.queryEntity(bizOrderConfigIdParam.getId());
    }

    @Override
    public BizOrderConfig queryEntity(String id) {
        BizOrderConfig bizOrderConfig = this.getById(id);
        if(ObjectUtil.isEmpty(bizOrderConfig)) {
            throw new CommonException("订单配置不存在，id值为：{}", id);
        }
        return bizOrderConfig;
    }

    @Override
    public Page<BizOrderConfig> getConfig(BizOrderConfigIdParam bizOrderConfigIdParam) {
        QueryWrapper<BizOrderConfig> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("boc.order_id",bizOrderConfigIdParam.getId()).
                eq("boc.delete_flag","NOT_DELETE");
        Page<BizOrderConfig> config = this.getBaseMapper().getConfig(CommonPageRequest.defaultPage(), queryWrapper);
        return config;
    }
}
