/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.goods.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.goods.entity.BizGoods;
import vip.xiaonuo.biz.modular.goods.param.BizGoodsAddParam;
import vip.xiaonuo.biz.modular.goods.param.BizGoodsEditParam;
import vip.xiaonuo.biz.modular.goods.param.BizGoodsIdParam;
import vip.xiaonuo.biz.modular.goods.param.BizGoodsPageParam;
import vip.xiaonuo.biz.modular.goods.service.BizGoodsService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 货品管理控制器
 *
 * @author 徐超
 * @date  2025/01/02 17:44
 */
@Tag(name = "货品管理控制器")
@RestController
@Validated
public class BizGoodsController {

    @Resource
    private BizGoodsService bizGoodsService;

    /**
     * 获取货品管理分页
     *
     * @author 徐超
     * @date  2025/01/02 17:44
     */
    @Operation(summary = "获取货品管理分页")
    @GetMapping("/biz/goods/page")
    public CommonResult<Page<BizGoods>> page(BizGoodsPageParam bizGoodsPageParam) {
        return CommonResult.data(bizGoodsService.page(bizGoodsPageParam));
    }

    /**
     * 添加货品管理
     *
     * @author 徐超
     * @date  2025/01/02 17:44
     */
    @Operation(summary = "添加货品管理")
    @CommonLog("添加货品管理")
    @SaCheckPermission("/biz/goods/add")
    @PostMapping("/biz/goods/add")
    public CommonResult<String> add(@RequestBody @Valid BizGoodsAddParam bizGoodsAddParam) {
        bizGoodsService.add(bizGoodsAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑货品管理
     *
     * @author 徐超
     * @date  2025/01/02 17:44
     */
    @Operation(summary = "编辑货品管理")
    @CommonLog("编辑货品管理")
    @SaCheckPermission("/biz/goods/edit")
    @PostMapping("/biz/goods/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizGoodsEditParam bizGoodsEditParam) {
        bizGoodsService.edit(bizGoodsEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除货品管理
     *
     * @author 徐超
     * @date  2025/01/02 17:44
     */
    @Operation(summary = "删除货品管理")
    @CommonLog("删除货品管理")
    @SaCheckPermission("/biz/goods/delete")
    @PostMapping("/biz/goods/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizGoodsIdParam> bizGoodsIdParamList) {
        bizGoodsService.delete(bizGoodsIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取货品管理详情
     *
     * @author 徐超
     * @date  2025/01/02 17:44
     */
    @Operation(summary = "获取货品管理详情")
    @GetMapping("/biz/goods/detail")
    public CommonResult<BizGoods> detail(@Valid BizGoodsIdParam bizGoodsIdParam) {
        return CommonResult.data(bizGoodsService.detail(bizGoodsIdParam));
    }

    /**
     * 获取货品列表
     *
     * @author 徐超
     * @date  2025/01/02 17:44
     */
    @Operation(summary = "获取货品管理详情")
    @GetMapping("/biz/goods/getList")
    public CommonResult<List<BizGoods>> getList(BizGoodsPageParam bizGoodsPageParam) {
        return CommonResult.data(bizGoodsService.getList(bizGoodsPageParam));
    }
}
