/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.openinterface.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.convert.Convert;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.cache.CommonCacheOperator;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.openinterface.entity.BizOpenInterface;
import vip.xiaonuo.biz.modular.openinterface.mapper.BizOpenInterfaceMapper;
import vip.xiaonuo.biz.modular.openinterface.param.BizOpenInterfaceAddParam;
import vip.xiaonuo.biz.modular.openinterface.param.BizOpenInterfaceEditParam;
import vip.xiaonuo.biz.modular.openinterface.param.BizOpenInterfaceIdParam;
import vip.xiaonuo.biz.modular.openinterface.param.BizOpenInterfacePageParam;
import vip.xiaonuo.biz.modular.openinterface.service.BizOpenInterfaceService;

import java.util.List;

/**
 * 应用管理Service接口实现类
 *
 * @author 徐超
 * @date  2025/04/08 13:25
 **/
@Service
public class BizOpenInterfaceServiceImpl extends ServiceImpl<BizOpenInterfaceMapper, BizOpenInterface> implements BizOpenInterfaceService {

    private static final String OpenInterfaceKey = "open-interface-*";
    @Resource
    private CommonCacheOperator commonCacheOperator;

    @Override
    public Page<BizOpenInterface> page(BizOpenInterfacePageParam bizOpenInterfacePageParam) {
        QueryWrapper<BizOpenInterface> queryWrapper = new QueryWrapper<BizOpenInterface>().checkSqlInjection();
        if(ObjectUtil.isAllNotEmpty(bizOpenInterfacePageParam.getSortField(), bizOpenInterfacePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizOpenInterfacePageParam.getSortOrder());
            queryWrapper.orderBy(true, bizOpenInterfacePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizOpenInterfacePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizOpenInterface::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizOpenInterfaceAddParam bizOpenInterfaceAddParam) {
        BizOpenInterface bizOpenInterface = BeanUtil.toBean(bizOpenInterfaceAddParam, BizOpenInterface.class);
        this.save(bizOpenInterface);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizOpenInterfaceEditParam bizOpenInterfaceEditParam) {
        BizOpenInterface bizOpenInterface = this.queryEntity(bizOpenInterfaceEditParam.getId());
        BeanUtil.copyProperties(bizOpenInterfaceEditParam, bizOpenInterface);
        this.updateById(bizOpenInterface);

        Object openInterfaceValue = commonCacheOperator.get(OpenInterfaceKey + bizOpenInterface.getAppKey());
        if(ObjectUtil.isNotNull(openInterfaceValue)) {
            commonCacheOperator.remove(OpenInterfaceKey + bizOpenInterface.getAppKey());
        }

    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizOpenInterfaceIdParam> bizOpenInterfaceIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizOpenInterfaceIdParamList, BizOpenInterfaceIdParam::getId));
        commonCacheOperator.removeBatch(OpenInterfaceKey);
    }

    @Override
    public BizOpenInterface detail(BizOpenInterfaceIdParam bizOpenInterfaceIdParam) {
        return this.queryEntity(bizOpenInterfaceIdParam.getId());
    }

    @Override
    public BizOpenInterface queryEntity(String id) {
        BizOpenInterface bizOpenInterface = this.getById(id);
        if(ObjectUtil.isEmpty(bizOpenInterface)) {
            throw new CommonException("应用管理不存在，id值为：{}", id);
        }
        return bizOpenInterface;
    }
}
