/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.receiptcompany.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.receiptcompany.entity.BizReceiptCompany;
import vip.xiaonuo.biz.modular.receiptcompany.mapper.BizReceiptCompanyMapper;
import vip.xiaonuo.biz.modular.receiptcompany.param.BizReceiptCompanyAddParam;
import vip.xiaonuo.biz.modular.receiptcompany.param.BizReceiptCompanyEditParam;
import vip.xiaonuo.biz.modular.receiptcompany.param.BizReceiptCompanyIdParam;
import vip.xiaonuo.biz.modular.receiptcompany.param.BizReceiptCompanyPageParam;
import vip.xiaonuo.biz.modular.receiptcompany.service.BizReceiptCompanyService;

import java.util.List;

/**
 * 收货单位Service接口实现类
 *
 * @author 徐超
 * @date  2025/01/02 17:45
 **/
@Service
public class BizReceiptCompanyServiceImpl extends ServiceImpl<BizReceiptCompanyMapper, BizReceiptCompany> implements BizReceiptCompanyService {

    @Override
    public Page<BizReceiptCompany> page(BizReceiptCompanyPageParam bizReceiptCompanyPageParam) {
        QueryWrapper<BizReceiptCompany> queryWrapper = new QueryWrapper<BizReceiptCompany>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizReceiptCompanyPageParam.getName())) {
            queryWrapper.lambda().like(BizReceiptCompany::getName, bizReceiptCompanyPageParam.getName());
        }
        if(ObjectUtil.isAllNotEmpty(bizReceiptCompanyPageParam.getSortField(), bizReceiptCompanyPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizReceiptCompanyPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizReceiptCompanyPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizReceiptCompanyPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizReceiptCompany::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizReceiptCompanyAddParam bizReceiptCompanyAddParam) {
        BizReceiptCompany bizReceiptCompany = BeanUtil.toBean(bizReceiptCompanyAddParam, BizReceiptCompany.class);
        this.save(bizReceiptCompany);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizReceiptCompanyEditParam bizReceiptCompanyEditParam) {
        BizReceiptCompany bizReceiptCompany = this.queryEntity(bizReceiptCompanyEditParam.getId());
        BeanUtil.copyProperties(bizReceiptCompanyEditParam, bizReceiptCompany);
        this.updateById(bizReceiptCompany);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizReceiptCompanyIdParam> bizReceiptCompanyIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizReceiptCompanyIdParamList, BizReceiptCompanyIdParam::getId));
    }

    @Override
    public BizReceiptCompany detail(BizReceiptCompanyIdParam bizReceiptCompanyIdParam) {
        return this.queryEntity(bizReceiptCompanyIdParam.getId());
    }

    @Override
    public BizReceiptCompany queryEntity(String id) {
        BizReceiptCompany bizReceiptCompany = this.getById(id);
        if(ObjectUtil.isEmpty(bizReceiptCompany)) {
            throw new CommonException("收货单位不存在，id值为：{}", id);
        }
        return bizReceiptCompany;
    }
}
