/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.record.mapper;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Param;
import vip.xiaonuo.biz.modular.record.entity.BizRecord;
import vip.xiaonuo.biz.modular.record.param.SevenDaysCountParam;
import vip.xiaonuo.biz.modular.record.result.CarResult;
import vip.xiaonuo.biz.modular.record.result.CompanyResult;
import vip.xiaonuo.biz.modular.record.result.GoodsResult;

import java.util.List;
import java.util.Map;

/**
 * 过磅记录Mapper接口
 *
 * @author 徐超
 * @date 2025/01/02 16:34
 **/
public interface BizRecordMapper extends BaseMapper<BizRecord> {

    Page<BizRecord> getPage(@Param("page") Page<BizRecord> page, @Param("ew") QueryWrapper<BizRecord> ew);

    List<BizRecord> getPage(@Param("ew") QueryWrapper<BizRecord> ew);

    // 查询7天总净重数据
    List<Map<String, Object>> sevenDaysTotalNetWeight(SevenDaysCountParam sevenDaysCountParam);

    // 查询七天总皮重数据
    List<Map<String, Object>> sevenDaysTotalTareWeight(SevenDaysCountParam sevenDaysCountParam);

    // 查询七天总毛重数据
    List<Map<String, Object>> sevenDaysTotalGrossWeight(SevenDaysCountParam sevenDaysCountParam);

    // 查询七天总车子数据
    List<Map<String, Object>> sevenDaysTotalCar(SevenDaysCountParam sevenDaysCountParam);

    // 查询总净重、总毛重、总皮重、总车次统计
    Map<String, Object> sevenDaysCountWeight(SevenDaysCountParam sevenDaysCountParam);

    // 收货单位统计
    List<CompanyResult> receiptCompanyCountList(SevenDaysCountParam sevenDaysCountParam);

    // 发货单位统计
    List<CompanyResult> shippingCompanyCountList(SevenDaysCountParam sevenDaysCountParam);

    // 运输单位统计
    List<CompanyResult> transportCompanyCountList(SevenDaysCountParam sevenDaysCountParam);

    // 货品统计
    List<GoodsResult> goodsCountList(SevenDaysCountParam sevenDaysCountParam);

    // 车牌统计
    List<CarResult> carCountList(SevenDaysCountParam sevenDaysCountParam);
}
