/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.shippingcompany.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.shippingcompany.entity.BizShippingCompany;
import vip.xiaonuo.biz.modular.shippingcompany.param.BizShippingCompanyAddParam;
import vip.xiaonuo.biz.modular.shippingcompany.param.BizShippingCompanyEditParam;
import vip.xiaonuo.biz.modular.shippingcompany.param.BizShippingCompanyIdParam;
import vip.xiaonuo.biz.modular.shippingcompany.param.BizShippingCompanyPageParam;
import vip.xiaonuo.biz.modular.shippingcompany.service.BizShippingCompanyService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 发货单位控制器
 *
 * @author 徐超
 * @date  2025/01/02 17:45
 */
@Tag(name = "发货单位控制器")
@RestController
@Validated
public class BizShippingCompanyController {

    @Resource
    private BizShippingCompanyService bizShippingCompanyService;

    /**
     * 获取发货单位分页
     *
     * @author 徐超
     * @date  2025/01/02 17:45
     */
    @Operation(summary = "获取发货单位分页")
    @SaCheckPermission("/biz/shippingcompany/page")
    @GetMapping("/biz/shippingcompany/page")
    public CommonResult<Page<BizShippingCompany>> page(BizShippingCompanyPageParam bizShippingCompanyPageParam) {
        return CommonResult.data(bizShippingCompanyService.page(bizShippingCompanyPageParam));
    }

    /**
     * 添加发货单位
     *
     * @author 徐超
     * @date  2025/01/02 17:45
     */
    @Operation(summary = "添加发货单位")
    @CommonLog("添加发货单位")
    @SaCheckPermission("/biz/shippingcompany/add")
    @PostMapping("/biz/shippingcompany/add")
    public CommonResult<String> add(@RequestBody @Valid BizShippingCompanyAddParam bizShippingCompanyAddParam) {
        bizShippingCompanyService.add(bizShippingCompanyAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑发货单位
     *
     * @author 徐超
     * @date  2025/01/02 17:45
     */
    @Operation(summary = "编辑发货单位")
    @CommonLog("编辑发货单位")
    @SaCheckPermission("/biz/shippingcompany/edit")
    @PostMapping("/biz/shippingcompany/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizShippingCompanyEditParam bizShippingCompanyEditParam) {
        bizShippingCompanyService.edit(bizShippingCompanyEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除发货单位
     *
     * @author 徐超
     * @date  2025/01/02 17:45
     */
    @Operation(summary = "删除发货单位")
    @CommonLog("删除发货单位")
    @SaCheckPermission("/biz/shippingcompany/delete")
    @PostMapping("/biz/shippingcompany/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizShippingCompanyIdParam> bizShippingCompanyIdParamList) {
        bizShippingCompanyService.delete(bizShippingCompanyIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取发货单位详情
     *
     * @author 徐超
     * @date  2025/01/02 17:45
     */
    @Operation(summary = "获取发货单位详情")
    @SaCheckPermission("/biz/shippingcompany/detail")
    @GetMapping("/biz/shippingcompany/detail")
    public CommonResult<BizShippingCompany> detail(@Valid BizShippingCompanyIdParam bizShippingCompanyIdParam) {
        return CommonResult.data(bizShippingCompanyService.detail(bizShippingCompanyIdParam));
    }
}
