/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.shippingcompany.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.shippingcompany.entity.BizShippingCompany;
import vip.xiaonuo.biz.modular.shippingcompany.mapper.BizShippingCompanyMapper;
import vip.xiaonuo.biz.modular.shippingcompany.param.BizShippingCompanyAddParam;
import vip.xiaonuo.biz.modular.shippingcompany.param.BizShippingCompanyEditParam;
import vip.xiaonuo.biz.modular.shippingcompany.param.BizShippingCompanyIdParam;
import vip.xiaonuo.biz.modular.shippingcompany.param.BizShippingCompanyPageParam;
import vip.xiaonuo.biz.modular.shippingcompany.service.BizShippingCompanyService;

import java.util.List;

/**
 * 发货单位Service接口实现类
 *
 * @author 徐超
 * @date  2025/01/02 17:45
 **/
@Service
public class BizShippingCompanyServiceImpl extends ServiceImpl<BizShippingCompanyMapper, BizShippingCompany> implements BizShippingCompanyService {

    @Override
    public Page<BizShippingCompany> page(BizShippingCompanyPageParam bizShippingCompanyPageParam) {
        QueryWrapper<BizShippingCompany> queryWrapper = new QueryWrapper<BizShippingCompany>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizShippingCompanyPageParam.getName())) {
            queryWrapper.lambda().like(BizShippingCompany::getName, bizShippingCompanyPageParam.getName());
        }
        if(ObjectUtil.isAllNotEmpty(bizShippingCompanyPageParam.getSortField(), bizShippingCompanyPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizShippingCompanyPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizShippingCompanyPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizShippingCompanyPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizShippingCompany::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizShippingCompanyAddParam bizShippingCompanyAddParam) {
        BizShippingCompany bizShippingCompany = BeanUtil.toBean(bizShippingCompanyAddParam, BizShippingCompany.class);
        this.save(bizShippingCompany);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizShippingCompanyEditParam bizShippingCompanyEditParam) {
        BizShippingCompany bizShippingCompany = this.queryEntity(bizShippingCompanyEditParam.getId());
        BeanUtil.copyProperties(bizShippingCompanyEditParam, bizShippingCompany);
        this.updateById(bizShippingCompany);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizShippingCompanyIdParam> bizShippingCompanyIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizShippingCompanyIdParamList, BizShippingCompanyIdParam::getId));
    }

    @Override
    public BizShippingCompany detail(BizShippingCompanyIdParam bizShippingCompanyIdParam) {
        return this.queryEntity(bizShippingCompanyIdParam.getId());
    }

    @Override
    public BizShippingCompany queryEntity(String id) {
        BizShippingCompany bizShippingCompany = this.getById(id);
        if(ObjectUtil.isEmpty(bizShippingCompany)) {
            throw new CommonException("发货单位不存在，id值为：{}", id);
        }
        return bizShippingCompany;
    }
}
