/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.transportcompany.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.transportcompany.entity.BizTransportCompany;
import vip.xiaonuo.biz.modular.transportcompany.param.BizTransportCompanyAddParam;
import vip.xiaonuo.biz.modular.transportcompany.param.BizTransportCompanyEditParam;
import vip.xiaonuo.biz.modular.transportcompany.param.BizTransportCompanyIdParam;
import vip.xiaonuo.biz.modular.transportcompany.param.BizTransportCompanyPageParam;
import vip.xiaonuo.biz.modular.transportcompany.service.BizTransportCompanyService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 运输单位控制器
 *
 * @author 徐超
 * @date  2025/01/02 17:46
 */
@Tag(name = "运输单位控制器")
@RestController
@Validated
public class BizTransportCompanyController {

    @Resource
    private BizTransportCompanyService bizTransportCompanyService;

    /**
     * 获取运输单位分页
     *
     * @author 徐超
     * @date  2025/01/02 17:46
     */
    @Operation(summary = "获取运输单位分页")
    @SaCheckPermission("/biz/transportcompany/page")
    @GetMapping("/biz/transportcompany/page")
    public CommonResult<Page<BizTransportCompany>> page(BizTransportCompanyPageParam bizTransportCompanyPageParam) {
        return CommonResult.data(bizTransportCompanyService.page(bizTransportCompanyPageParam));
    }

    /**
     * 添加运输单位
     *
     * @author 徐超
     * @date  2025/01/02 17:46
     */
    @Operation(summary = "添加运输单位")
    @CommonLog("添加运输单位")
    @SaCheckPermission("/biz/transportcompany/add")
    @PostMapping("/biz/transportcompany/add")
    public CommonResult<String> add(@RequestBody @Valid BizTransportCompanyAddParam bizTransportCompanyAddParam) {
        bizTransportCompanyService.add(bizTransportCompanyAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑运输单位
     *
     * @author 徐超
     * @date  2025/01/02 17:46
     */
    @Operation(summary = "编辑运输单位")
    @CommonLog("编辑运输单位")
    @SaCheckPermission("/biz/transportcompany/edit")
    @PostMapping("/biz/transportcompany/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizTransportCompanyEditParam bizTransportCompanyEditParam) {
        bizTransportCompanyService.edit(bizTransportCompanyEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除运输单位
     *
     * @author 徐超
     * @date  2025/01/02 17:46
     */
    @Operation(summary = "删除运输单位")
    @CommonLog("删除运输单位")
    @SaCheckPermission("/biz/transportcompany/delete")
    @PostMapping("/biz/transportcompany/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizTransportCompanyIdParam> bizTransportCompanyIdParamList) {
        bizTransportCompanyService.delete(bizTransportCompanyIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取运输单位详情
     *
     * @author 徐超
     * @date  2025/01/02 17:46
     */
    @Operation(summary = "获取运输单位详情")
    @SaCheckPermission("/biz/transportcompany/detail")
    @GetMapping("/biz/transportcompany/detail")
    public CommonResult<BizTransportCompany> detail(@Valid BizTransportCompanyIdParam bizTransportCompanyIdParam) {
        return CommonResult.data(bizTransportCompanyService.detail(bizTransportCompanyIdParam));
    }
}
